mise-lib
========

Collection of common tasks for mise

Some tasks intended as either global tasks, or remote tasks in repositories.
These tasks are of a generic nature, which makes them applicable to many of my repositories.
For that reason, it makes sense to maintain them in one place, and use mise remote tasks to refer to them.

Some tasks are more global in nature, and designed to be referred to (again, as remote tasks) from your global mise config.
